@@ -20,6 +20,7 @@ pub struct Args {
     // flags
     pub full_screen: bool,
     pub inline: bool,
+    pub preserve_order: bool,
 
     // options
     pub lines: Option<usize>,
@@ -38,6 +39,8 @@ pub struct Cfg {
     pub screen: ScreenConfig,
     #[serde(default)]
     pub initial_query: Option<String>,
+    #[serde(default)]
+    pub preserve_order: bool,
 
     #[serde(default)]
     pub prompt: PromptConfig,
@@ -124,6 +127,10 @@ impl Configurator {
                 }
             }
 
+            if args.preserve_order {
+                config.preserve_order = true;
+            }
+
             if let Some(q) = &args.search {
                 let q = q.to_string();
                 config.initial_query = Some(q);
